@@ -8,7 +8,7 @@ our @EXPORT_OK = qw(
     collect
 );
 
-our $VERSION = '0.0.18';
+our $VERSION = '0.0.19';
 
 use List::Util;
 use Scalar::Util qw(blessed);
@@ -328,10 +328,10 @@ sub indexOf {
 sub intersect {
     my ($self, $other_collection, $key) = @_;
 
-    $key ||= 'primary_key';
+    $key ||= $self->model->primary_key;
 
     return $self->search({
-        $self->model->$key => $other_collection->lists($other_collection->model->$key),
+        $key => $other_collection->lists($key),
     });
 }
 
@@ -411,10 +411,10 @@ sub min {
 sub missing {
     my ($self, $other_collection, $key) = @_;
 
-    $key ||= 'primary_key';
+    $key ||= $self->model->primary_key;
 
     return $self->exclude({
-        $self->model->$key => $other_collection->lists($other_collection->model->$key),
+        $key => $other_collection->lists($key),
     });
 }
 
